@@ -3,13 +3,14 @@ Main interface for sdb service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.sdb import (
+    from mypy_boto3_sdb import (
         Client,
         ListDomainsPaginator,
         SelectPaginator,
         SimpleDBClient,
-        )
+    )
 
     session = boto3.Session()
 
@@ -18,8 +19,9 @@ Usage::
 
     list_domains_paginator: ListDomainsPaginator = client.get_paginator("list_domains")
     select_paginator: SelectPaginator = client.get_paginator("select")
+    ```
 """
-from mypy_boto3_sdb.client import SimpleDBClient as Client, SimpleDBClient
+from mypy_boto3_sdb.client import SimpleDBClient, SimpleDBClient as Client
 from mypy_boto3_sdb.paginator import ListDomainsPaginator, SelectPaginator
 
 
