@@ -3,13 +3,15 @@ Main interface for sdb service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.sdb import SimpleDBClient
+    from mypy_boto3_sdb import SimpleDBClient
 
     session = boto3.Session()
 
     client: SimpleDBClient = boto3.client("sdb")
     session_client: SimpleDBClient = session.client("sdb")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
@@ -89,7 +91,7 @@ class SimpleDBClient:
         self,
         DomainName: str,
         ItemName: str,
-        Attributes: List[AttributeTypeDef] = None,
+        Attributes: List["AttributeTypeDef"] = None,
         Expected: UpdateConditionTypeDef = None,
     ) -> None:
         """
@@ -139,7 +141,7 @@ class SimpleDBClient:
         self,
         DomainName: str,
         ItemName: str,
-        Attributes: List[ReplaceableAttributeTypeDef],
+        Attributes: List["ReplaceableAttributeTypeDef"],
         Expected: UpdateConditionTypeDef = None,
     ) -> None:
         """
